﻿using System;
using System.Linq;
using System.Windows.Controls;
using Telerik.Windows.Controls.TreeView;
using Telerik.Windows.DragDrop;

namespace TreeView_SL_DragDrop
{
	public partial class MainPage : UserControl
	{
		public MainPage()
		{
			this.InitializeComponent();

			this.DataContext = new MainVM();

			DragDropManager.AddDropHandler(this.xIntTree, new DragEventHandler(OnIntTreeDrop), true);
			DragDropManager.AddDropHandler(this.xStringTree, new DragEventHandler(OnStringTreeDrop), true);
			DragDropManager.AddDragDropCompletedHandler(this.xIntTree, new DragDropCompletedEventHandler(OnIntTreeDragDropCompleted), true);
			DragDropManager.AddDragDropCompletedHandler(this.xStringTree, new DragDropCompletedEventHandler(OnStringTreeDragDropCompleted), true);
		}

		void OnIntTreeDrop(object sender, DragEventArgs e)
		{
			/*Restrict the default drop logic*/
			var options = DragDropPayloadManager.GetDataFromObject(e.Data, TreeViewDragDropOptions.Key) as TreeViewDragDropOptions;
			if (options != null)
			{
				options.DropAction = DropAction.None;
			}
		}

		void OnIntTreeDragDropCompleted(object sender, DragDropCompletedEventArgs e)
		{
			/*Implement your custom drop logic*/
			TreeViewDragDropOptions dragDropOptions = DragDropPayloadManager.GetDataFromObject(e.Data, TreeViewDragDropOptions.Key) as TreeViewDragDropOptions;
			if (dragDropOptions != null)
			{
				//if you drop over the xStringTree tree
				if (dragDropOptions.DropTargetTree != null && dragDropOptions.DropTargetTree.Name.ToString() == "xStringTree")
				{
					IntItem draggedItem = dragDropOptions.DraggedItems.FirstOrDefault() as IntItem;
					if (draggedItem != null)
					{
						string newHeader = draggedItem.Header.ToString();
						(xIntTree.DataContext as MainVM).StringSource.Add(new StringItem() { Header = newHeader });
					}
				}
				else
				{
					//You have dropped over an StringItem or outside the xStringTree
				}
			}
		}

		void OnStringTreeDrop(object sender, DragEventArgs e)
		{
			/*Restrict the default drop logic*/
			var options = DragDropPayloadManager.GetDataFromObject(e.Data, TreeViewDragDropOptions.Key) as TreeViewDragDropOptions;
			if (options != null)
			{
				options.DropAction = DropAction.None;
			}
		}

		void OnStringTreeDragDropCompleted(object sender, DragDropCompletedEventArgs e)
		{
			/*Implement your custom drop and convert logic*/
			TreeViewDragDropOptions dragDropOptions = DragDropPayloadManager.GetDataFromObject(e.Data, TreeViewDragDropOptions.Key) as TreeViewDragDropOptions;
			if (dragDropOptions != null)
			{
				//if you drop over the xIntTree tree 
				if (dragDropOptions.DropTargetTree != null && dragDropOptions.DropTargetTree.Name.ToString() == "xIntTree")
				{
					StringItem draggedItem = dragDropOptions.DraggedItems.FirstOrDefault() as StringItem;
					if (draggedItem != null)
					{
						int newHeader = int.Parse(draggedItem.Header);
						(xIntTree.DataContext as MainVM).IntSource.Add(new IntItem() { Header = newHeader });
					}
				}
				else
				{
					//You have dropped over an IntItem or outside the xIntTree
				}
			}
		}
	}
}